pub enum ArraySize {
Unspecified,
Star,
Expr(Box<Expr>),
}Expand description
The size of an array derivation.
Variants
Unspecified
[] — an incomplete array type.
Star
[*] — a variable length array of unspecified size, only valid in a
function prototype.
Expr(Box<Expr>)
[expr]. Whether this is a constant array bound or a VLA is decided by
constant evaluation in sema.