pub struct Local {
pub object: ObjectId,
pub rust_name: String,
}Expand description
A local variable hoisted to the top of the function.
Fields
object: ObjectIdThe object it defines.
rust_name: StringThe Rust name it is given, unique within the function.