div_f32

Function div_f32 

pub fn div_f32((a, b): Parts, (c, d): Parts) -> Parts
The quotient of two float _Complex constants: the closed form in double, which cannot overflow for float operands, with the same recovery and a single rounding at the end.