long_double_math

Function long_double_math 

pub fn long_double_math(rest: &str) -> Option<&'static str>
The maths functions whose long double form is the double one here.

long double is double in cinrs — no portable Rust type has an x87 extended double’s layout — so __builtin_sqrtl may not become a call to the platform’s sqrtl, whose argument and result would be an eighty-bit value the generated Rust cannot pass. It becomes a call to sqrt, which is the same function at the width this implementation gives the type.