AtomicRmw

Enum AtomicRmw 

pub enum AtomicRmw {
    Add,
    Sub,
    And,
    Or,
    Xor,
    Nand,
}
The arithmetic a AtomicOp::Rmw performs.

Variants



Add

+



Sub

-



And

&



Or

|



Xor

^



Nand

~(a & b), which Rust has no fetch_nand for on the integers and which is therefore a fetch_update.

Implementations

Source

impl AtomicRmw

pub fn rust_method(self) -> Option<&'static str>

The core::sync::atomic method that performs it, where there is one.

pub fn c_op(self) -> &'static str

The C operator, for a diagnostic.